@@ -30,7 +30,6 @@ case "della tariffa arrotondato a":  		$messaggio = "тарифа округле
 case "considera il costo percentuale come letto(i) aggiuntivo(i)":	$messaggio = "рассматривать эту процентную стоимость как добавочное место(а)"; break;
 case "Procedi nell'inserimento del nuovo costo aggiuntivo":	$messaggio = "Продолжить добавление нового дополнительного расхода"; break;
 case "Caparra":  				$messaggio = "Депозит"; break;
-case "La caparra normale per la":  		$messaggio = "Нормальный депозит для"; break;
 case "arrotondata a":  				$messaggio = "округлен до"; break;
 case "Inserisci o modifica la caparra":  	$messaggio = "Вставить или изменить депозит"; break;
 case "Vedi i prezzi già inseriti":  		$messaggio = "Посмотреть цены уже вставленные"; break;
@@ -206,7 +205,9 @@ case "Sulla":  					$messaggio = "On"; break;
 case "p":  					$messaggio = "p"; break;
 case "Se":  					$messaggio = "If"; break;
 case "Se si inseriscono":  			$messaggio = "If"; break;
+case "a":  					$messaggio = "to"; break;
 case "Crea Prezzi":  				$messaggio = "Insert Prices"; break;
+case "La caparra normale per":  		$messaggio = "The normal deposit for"; break;
 case "già esiste, vai alla pagina di visualizzazione periodi e tariffe per cancellarlo":	$messaggio = "already exists, go to the page with the periods and the rates to delete it"; break;
 case "già esiste, usa il tasto \"modifica i prezzi già inseriti\" per cambiarlo o non metterlo per inserire prezzi per nuovi periodi":	$messaggio = "already exists, use the button \"modify already inserted prices\" to change it, or don't insert it to insert prices in new periods"; break;
 case "già esiste, ne devi usare un'altro":  	$messaggio = "already exists, you must use another one"; break;
@@ -236,7 +237,7 @@ case "per settimana":  				$messaggio = "per week"; break;
 case "per giorno":  				$messaggio = "per day"; break;
 case "La caparra è errata":  			$messaggio = "The deposit is wrong"; break;
 case "Commissioni":  				$messaggio = "Commissions"; break;
-case "Le commissioni normali sulla":  		$messaggio = "The normal commissions on"; break;
+case "Le commissioni normali su":  		$messaggio = "The normal commissions on"; break;
 case "Inserisci o modifica le commissioni":  	$messaggio = "Insert or modify commissions"; break;
 case "Tasse":  					$messaggio = "Taxes"; break;
 case "Tasse applicate su":  			$messaggio = "Taxes applied on"; break;
@@ -258,6 +259,9 @@ case "il prezzo della tariffa per le prime":  	$messaggio = "the rate price for
 case "della":  					$messaggio = "of the"; break;
 case "tariffa + sconto":  			$messaggio = "rate + discount"; break;
 case "tariffa + sconto + costi agg.":  		$messaggio = "rate + discount + extra costs"; break;
+case "della tar.":  				$messaggio = "of rate"; break;
+case "di t.+s.":  				$messaggio = "of r.+d."; break;
+case "di t.+s.+c.a.":  				$messaggio = "of r.+d.+e.c."; break;
 case "Nome della":  				$messaggio = "Name of"; break;
 case "Cambia":  				$messaggio = "Change"; break;
 case "prezzo per settimana":  			$messaggio = "price per week"; break;
@@ -321,6 +325,12 @@ case "questi tipi":  				$messaggio = "these types"; break;
 case "Mostrare come tipo di persona":  		$messaggio = "Display as person type"; break;
 case "Applicare la percentuale del tipo di persona al prezzo del costo":	$messaggio = "Apply the percentage of the person type to the price of the cost"; break;
 case "Neonati (0-23 mesi)":  			$messaggio = "Infants (0-23 months)"; break;
+case "tariffe con":  				$messaggio = "rates with"; break;
+case "per persona nullo":  			$messaggio = "per person zero"; break;
+case "fisso nullo":  				$messaggio = "fixed zero"; break;
+case "da per persona":  			$messaggio = "from per person"; break;
+case "più fisso":  				$messaggio = "from fixed"; break;
+case "dal fisso":  				$messaggio = "plus fixed"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
