@@ -186,6 +186,7 @@ case "Codice fiscale":  			$messaggio = "Финансовый код"; break;
 case "Origine":  				$messaggio = "Источник"; break;
 case "tutte":  					$messaggio = "all"; break;
 case "ln.":  					$messaggio = "ln."; break;
+case "id op.":  				$messaggio = "id"; break;
 case "Modifica Prenotazioni":  			$messaggio = "Modify reservations"; break;
 case "La prenotazione è dell'anno precedente, si potrà modificare solo la data finale":	$messaggio = "The reservation is from previus year, you will be able to modify only the final date"; break;
 case "documento di tipo":  			$messaggio = "document type"; break;
@@ -269,6 +270,34 @@ case "Prenotazioni cancellate":  		$messaggio = "Deleted reservations"; break;
 case "Data o orario stimato di entrata <span class=\"colred\">errato</span>":	$messaggio = "<span class=\"colred\">Wrong</span> estimated check-in time or date"; break;
 case "Data cancellazione":  			$messaggio = "Deletion date"; break;
 case "Cancellata dall'utente":  		$messaggio = "Deleted by user"; break;
+case "Per la tariffa selezionata si deve inserire un <span class=\"colred\">numero minimo</span> di":	$messaggio = "For selected rate you have to insert a <span class=\"colred\">minimum number</span> of"; break;
+case "persona":  				$messaggio = "person"; break;
+case "id operazione":  				$messaggio = "transaction id"; break;
+case "Data operazione":  			$messaggio = "Transaction date"; break;
+case "Data":  					$messaggio = "Date"; break;
+case "Note":  					$messaggio = "Notes"; break;
+case "Informazioni extra":  			$messaggio = "Extra info"; break;
+case "Inserisci una prenotazione uguale":  	$messaggio = "Insert a reservation like this"; break;
+case "Inserisci prenotazioni uguali":  		$messaggio = "Insert reservations like these"; break;
+case "Cambia il cliente anche nei pagamenti effettuati":	$messaggio = "Change client also in payments already made"; break;
+case "Ripristina la prenotazione":  		$messaggio = "Restore reservation"; break;
+case "Ripristina le prenotazioni":  		$messaggio = "Restore reservations"; break;
+case "Non si possono inserire prenotazioni nel passato":	$messaggio = "You can't insert reservations in the past"; break;
+case "Si è sicuri di voler provare a <b>ripristinare</b> la prenotazione":	$messaggio = "Are you sure you want to try <b>restoring</b> the reservation"; break;
+case "Si è sicuri di voler provare a <b>ripristinare</b> le prenotazioni":	$messaggio = "Are you sure you want to try <b>restoring</b> reservations"; break;
+case "ripristinata":  				$messaggio = "restored"; break;
+case "Le date della prenotazione":  		$messaggio = "The reservation dates"; break;
+case "non sono attualmente disponibili":  	$messaggio = "are not currently available"; break;
+case "sono attualmente chiuse":  		$messaggio = "are currently closed"; break;
+case "Le date vanno liberate manualmente prima di poter ripristinare la prenotazione":	$messaggio = "Dates must be manually freed before the reservation can be restored"; break;
+case "Le prenotazioni vicine alla prenotazione":	$messaggio = "Reservations nearby reservation"; break;
+case "vanno ripristinate manualemnte":  	$messaggio = "must be restored manually"; break;
+case "cancellare manualmente una prenotazione proveniente dalle interconnessioni":	$messaggio = "manually deleting a reservation coming from interconnections"; break;
+case "senza aspettare che venga cancellata dall'interconnessione":	$messaggio = "without waiting for it to be deleted by the interconnection"; break;
+case "può creare overbooking":  		$messaggio = "may cause overbooking"; break;
+case "rimpicciolire manualmente una prenotazione proveniente dalle interconnessioni":	$messaggio = "manually shrinking a reservation coming from interconnections"; break;
+case "senza aspettare che venga modificata dall'interconnessione":	$messaggio = "without waiting for it to be modified by the interconnection"; break;
+case "gli altri campi":  			$messaggio = "the other fields"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
