@@ -71,25 +71,6 @@ case "spazio":  				$messaggio = "пробел"; break;
 case "trattino":  				$messaggio = "дефис"; break;
 case "a capo":  				$messaggio = "новая строка"; break;
 case "Pagine per il sito web":  		$messaggio = "Страницы Web-сайта"; break;
-case " Do":  					$messaggio = " Вс"; break;
-case " Lu":  					$messaggio = " Пн"; break;
-case " Ma":  					$messaggio = " Вт"; break;
-case " Me":  					$messaggio = " Ср"; break;
-case " Gi":  					$messaggio = " Чт"; break;
-case " Ve":  					$messaggio = " Пт"; break;
-case " Sa":  					$messaggio = " Сб"; break;
-case "Gen":  					$messaggio = "Янв"; break;
-case "Feb":  					$messaggio = "Фев"; break;
-case "Mar":  					$messaggio = "Мар"; break;
-case "Apr":  					$messaggio = "Apr"; break;
-case "Mag":  					$messaggio = "Май"; break;
-case "Giu":  					$messaggio = "Июн"; break;
-case "Lug":  					$messaggio = "Июл"; break;
-case "Ago":  					$messaggio = "Авг"; break;
-case "Set":  					$messaggio = "Сен"; break;
-case "Ott":  					$messaggio = "Окт"; break;
-case "Nov":  					$messaggio = "Ноя"; break;
-case "Dic":  					$messaggio = "Дек"; break;
 case "nome della tariffa":  			$messaggio = "название тарифа"; break;
 case "data di inserimento":  			$messaggio = "добавление данных"; break;
 case "tariffa completa":  			$messaggio = "полная цена"; break;
@@ -158,7 +139,6 @@ case "Il mascheramento della provenienza delle email è stato cambiato":	$messag
 case "SI":  					$messaggio = "ДА"; break;
 case "NO":  					$messaggio = "НЕТ"; break;
 case "Cartelle in cui creare le pagine per il sito web":	$messaggio = "Папки, в которых создаются страницы сайта"; break;
-case "percorsi separati da virgole relativi":	$messaggio = "список папок через запятую, относительно папки"; break;
 case "alla cartella di HotelDruid, se non iniziano con /":	$messaggio = "HotelDruid, если начинается не с /"; break;
 case "Non ho i permessi di scrittura sulla cartella":	$messaggio = "Не разрешена запись в папку"; break;
 case "La cartella inserita <div style=\"display: inline; color: red;\">non esiste</div>":	$messaggio = "Указанная папка <div style=\"display: inline; color: red;\">не существует</div>"; break;
@@ -471,9 +451,30 @@ case "nella gestione del suo DNS va aggiunto un record TXT contenente un testo c
 case "Questo è il record SPF attuale del dominio":	$messaggio = "This is the current SPF record of the domain"; break;
 case "questo record TXT va modificato nella gestione del DNS del dominio":	$messaggio = "this TXT record must be modified in the management of DNS of the domain"; break;
 case "sostituendolo con un testo come questo":	$messaggio = "replacing it with a text like this"; break;
+case "Dopo la modifica potrebbero volerci alcune ore affinchè l'aggiornamento sia attivo":	$messaggio = "After the change it may take a few hours for the update to take effect"; break;
+case "Formato di nomi e cognomi":  		$messaggio = "Format of names and surnames"; break;
+case "non modificare il formato inserito":  	$messaggio = "don't modify inserted format"; break;
+case "prima lettera maiuscola, altre lettere minuscole":	$messaggio = "first letter uppercase, other letters lowercase"; break;
+case "prima lettera maiuscola, non modificare altre lettere":	$messaggio = "first letter uppercase, do not change other letters"; break;
+case "tutte lettere maiuscole":  		$messaggio = "all letters uppercase"; break;
+case "tutte lettere minuscole":  		$messaggio = "all letters lowercase"; break;
+case "Il formato di inserimento dei nomi e cognimi è stato cambiato":	$messaggio = "The format for inserting names and surnames has been changed"; break;
+case "Per il proprio indirizzo email si sta usando un provider pubblico":	$messaggio = "For your email address you are using a public provider"; break;
+case "si consiglia quindi di":  		$messaggio = "it is therefore advisable to"; break;
+case "configurare il loro server remoto smtp":	$messaggio = "configure their remote smtp server"; break;
+case "per inviare email":  			$messaggio = "to avoid that emails sent"; break;
+case "da hoteldruid":  				$messaggio = "from hoteldruid"; break;
+case "senza che vengano considerate come spam":	$messaggio = "are considered as spam"; break;
+case "percorsi relativi":  			$messaggio = "paths relative"; break;
+case "Secondo cognome disattivato":  		$messaggio = "Second surname disabled"; break;
+case "Secondo cognome attivato":  		$messaggio = "Second surname enabled"; break;
+case "Fuso orario":  				$messaggio = "Time zone"; break;
+case "nessun fuso orario":  			$messaggio = "no time zone"; break;
+case "Si possono creare solo cartelle con nome composto da lettere e numeri":	$messaggio = "Only folders with names that contain letters and numbers can be created"; break;
+case "la seguente cartella verrà creata":  	$messaggio = "the following folder will be created"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
 } # fine switch ($messaggio)
 
-?>
\ No newline at end of file
+?>
