@@ -230,6 +230,8 @@ case "giorno":  				$messaggio = "day"; break;
 case "p":  					$messaggio = "p"; break;
 case "Aggiungi":  				$messaggio = "Add"; break;
 case "e":  					$messaggio = "and"; break;
+case "Id":  					$messaggio = "Id"; break;
+case "chiedere":  				$messaggio = "ask"; break;
 case "Visualizza Tabelle":  			$messaggio = "View Tables"; break;
 case "Tutte le spese del":  			$messaggio = "All expenses of"; break;
 case "nella cassa principale":  		$messaggio = "in main cashbox"; break;
@@ -365,7 +367,6 @@ case "al cambio attuale":  			$messaggio = "at current exchange rate"; break;
 case "Le altre valute presenti nella cassa":  	$messaggio = "Other currencies in cashbox"; break;
 case "sono state convertite in":  		$messaggio = "have been converted into"; break;
 case "Tabella con le prenotazioni cancellate":	$messaggio = "Table with deleted reservations"; break;
-case "Prenotazioni cancellate":  		$messaggio = "Deleted reservations"; break;
 case "<b>non importare</b> i prezzi":  		$messaggio = "<b>do not import</b> prices"; break;
 case "Attenzione":  				$messaggio = "Notice"; break;
 case "i periodi aggiunti non potranno più essere eliminati":	$messaggio = "periods added now can't be deleted later"; break;
@@ -374,9 +375,16 @@ case "e applica la % del tipo di persona":  	$messaggio = "and apply the % of pe
 case "escludendo":  				$messaggio = "excluding"; break;
 case "includendo solo":  			$messaggio = "including only"; break;
 case "Superato il massimo numero di anni comparabili":	$messaggio = "Exceeded the maximum number of comparable years"; break;
+case "Numero_predefinito di persone":  		$messaggio = "Default_number of people"; break;
+case "Numero_minimo di persone":  		$messaggio = "Minimum_number of people"; break;
+case "Cancellare anche":  			$messaggio = "Delete also"; break;
+case "clienti con solo prenotazioni cancellate negli anni passati, cancellando le loro prenotazioni in modo permanente":	$messaggio = "clients with only deleted reservations in past years, deleting their reservations permanently"; break;
+case "Prenotazioni cancellate":  		$messaggio = "Deleted reservations"; break;
+case "Anche cancellate":  			$messaggio = "Also deleted"; break;
+case "Solo cancellate":  			$messaggio = "Only deleted"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
 } # fine switch ($messaggio)
 
-?>
\ No newline at end of file
+?>
